@@ -20,6 +20,7 @@ use Symbol                  qw( qualify_to_ref  );
 use Module::FromPerlVer::Util
 qw
 (
+    search_bin
     search_cwd
 );
 
@@ -27,7 +28,7 @@ qw
 # package variables & sanity checks
 ########################################################################
 
-our $VERSION    = version->parse( 'v0.1.1' )->numify;
+our $VERSION    = version->parse( 'v0.1.2' )->numify;
 my $verbose     = $ENV{ VERBOSE_FROMPERLVER };
 
 my $nil         = sub{};
@@ -48,9 +49,9 @@ my @restore     = qw( git checkout  --theirs                    );
 my $search_for
 = sub
 {
-    &search_cwd 
+    search_cwd( @_ )
     or
-    &search_bin
+    search_bin( @_ )
 };
 
 my @handlerz = 
